{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_id %}update_lease{% endblock %}
{% block form_action %}{% url 'horizon:project:leases:update' lease.id %}{% endblock %}

{% block modal_id %}update_lease_modal{% endblock %}

{% block modal-body %}
<div class="left">
    <fieldset>
    {% include "horizon/common/_form_fields.html" %}
    </fieldset>
</div>
<div class="right">
    <h3>{% trans "Description" %}:</h3>
    <p>{% trans "Update a lease with the provided values." %}</p>
</div>
{% endblock %}

{% block modal-footer %}
  <a href="{% url 'horizon:project:leases:index' %}" class="btn btn-default cancel">{% trans "Cancel" %}</a>
  <input class="btn btn-primary pull-right" type="submit" value="{% trans "Update" %}" />
{% endblock %}
